==> ckeditor_alert-7.x-1.0.tar.gz: ckeditor_alert/plugins/alert/plugin.js <==
/*
* Alert Box Plugin
*
* @author Sagar Boina <sagar.sijju@gmail.com>
* @version 1.0
*/
(function () {
    CKEDITOR.plugins.add( 'alert', {
        icons: 'alert',
        init: function( editor ) {
            editor.addCommand( 'alert', new CKEDITOR.dialogCommand( 'alert' ) );
            editor.ui.addButton( 'alert', {
                label: 'Add Alert Message',
                command: 'alert',
                toolbar: 'insert'
     
            });
            let plugin_path = this.path;
			
			
			CKEDITOR.dialog.add('alert', function (instance) {
				return {
					title: 'Alert Message',
					minWidth: 400,
					minHeight: 200,
					contents: [
						{
							id: 'AlertPlugin',
							label: 'Basic Settings',
							elements: [
								{
									type: 'textarea',
									id: 'alert_text',
									label: 'Alert Message',
									setup: function( element ) {
										this.setValue( element.getText() );
									},
									commit: function( element ) {
										element.setText( this.getValue() );
									}
								}
							]
						}
					],
					onShow: function() {
						var selection = editor.getSelection();
						var element = selection.getStartElement();
						this.element = element;
						this.setupContent( this.element );						
					},
					onOk: function() {
						var txt = this.getValueOf('AlertPlugin', 'alert_text');
						var list_txt = '<span class="alert-box">'+txt+'</span>';
						editor.insertHtml( list_txt );
					}
				}
			}); //dialog ends
    } //init ends
	}) //add ends
})()

==> ckeditor_alert-7.x-1.1.tar.gz: ckeditor_alert/plugins/alert/plugin.js <==
/*
* Alert Box Plugin
*
* @author Sagar Boina <sagar.sijju@gmail.com>
* @version 1.0
*/
(function () {
    CKEDITOR.plugins.add( 'alert', {
        icons: 'alert',
        init: function( editor ) {
            editor.addCommand( 'alert', new CKEDITOR.dialogCommand( 'alert' ) );
            editor.ui.addButton( 'alert', {
                label: 'Add Alert Message',
                command: 'alert',
                toolbar: 'insert'
     
            });
            let plugin_path = this.path;
			
			
			CKEDITOR.dialog.add('alert', function (editor) {
				return {
					title: 'Alert Message',
					minWidth: 400,
					minHeight: 200,
					contents: [
						{
							id: 'AlertPlugin',
							label: 'Basic Settings',
							elements: [
								{
									type: 'textarea',
									id: 'alert_text',
									label: 'Alert Message',
									setup: function( element ) {
										this.setValue( element.getText() );
									},
									commit: function( element ) {
										element.setText( this.getValue() );
									}
								}
							]
						}
					],
					onShow: function() {
						var selection = editor.getSelection();
						var element = selection.getStartElement();
						this.element = element;
						this.setupContent( this.element );						
					},
					onOk: function() {
						var txt = this.getValueOf('AlertPlugin', 'alert_text');
						var list_txt = '<span class="alert-box">'+txt+'</span>';
						editor.insertHtml( list_txt );
					}
				}
			}); //dialog ends
    } //init ends
	}) //add ends
})()
